..
      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.


Developer Guide
===============

In the Developer Guide, you will find information on networking-odl's lower
level design and implementation details. We will cover only essentials details
related to just networking-odl and we won't repeat neutron devref here, for
details in neutron, neutron's devref can be checked ::

    https://github.com/openstack/neutron/tree/master/doc/source/devref

For details regarding OpenStack Neutron's Api ::

    https://github.com/openstack/neutron-lib/tree/master/api-ref/source


Contents:

.. toctree::
   :maxdepth: 2

   drivers_architecture
   hostconfig
   maintenance
   testing

.. include:: ../../../vagrant/README.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

